# NeuReQua: Neuronal Recording Quality Check

🧠 NeuReQua is a Python library designed to help you monitoring your signal quality acquired with micro-electrodes

With NeuReQua you can:
- Load your data in multiple file formats (.ncs, .nsX, .med)
- Compute quality metrics on portion of signals to check that everything is ok
- Identify artifacts in your signal and remove it to improve your spike sorting for example
- Analyze functional response during your cognitive task and identify artifacted channels and/or trials


## Installation 

Download Quality_Notebook.ipynb

and then type the following line in your command window

```bash
 pip install neurequa
```

If you have any suggestion feel free to contact me

📧 : vincent.dornier@cnrs.fr
